<?php
/**
* Post meta functions
*
* @package GridBit WordPress Theme
* @copyright Copyright (C) 2023 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'gridbit_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function gridbit_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridbit' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="gridbit-tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'gridbit' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


function gridbit_author_image_size() {
    global $post;
    $gravatar_size = 28;
    return apply_filters( 'gridbit_author_image_size', $gravatar_size );
}


if ( ! function_exists( 'gridbit_author_image' ) ) :
function gridbit_author_image( $size = '' ) {
    global $post;
    if ( $size ) {
        $gravatar_size = $size;
    } else {
        $gravatar_size = gridbit_author_image_size();
    }
    $author_email   = get_the_author_meta( 'user_email' );
    $gravatar_args  = apply_filters(
        'gridbit_gravatar_args',
        array(
            'size' => $gravatar_size,
        )
    );

    $avatar_url = '';
    if( get_the_author_meta('themesdna_userprofile_image',get_query_var('author') ) ) {
        $avatar_url = get_the_author_meta( 'themesdna_userprofile_image' );
    } else {
        $avatar_url = get_avatar_url( $author_email, $gravatar_args );
    }

    //$avatar_url     = get_avatar_url( $author_email, $gravatar_args );
    if ( gridbit_get_option('author_image_link') ) {
        $avatar_markup  = '<a href="'.esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ).'" title="'.esc_attr( get_the_author() ).'"><img class="gridbit-grid-post-author-image" alt="' . esc_attr( get_the_author() ) . '" src="' . esc_url( $avatar_url ) . '" /></a>';
    } else {
        $avatar_markup  = '<img class="gridbit-grid-post-author-image" alt="' . esc_attr( get_the_author() ) . '" src="' . esc_url( $avatar_url ) . '" />';
    }
    return apply_filters( 'gridbit_author_image', $avatar_markup );
}
endif;


if ( ! function_exists( 'gridbit_grid_header_meta' ) ) :
function gridbit_grid_header_meta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbit_get_option('hide_post_author_home')) || !(gridbit_get_option('hide_post_author_image_home')) || !(gridbit_get_option('hide_posted_date_home')) || (!(gridbit_get_option('hide_comments_link_home')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) { ?>
    <div class="gridbit-grid-thumbnail-meta gridbit-grid-post-block">
    <div class="gridbit-grid-thumbnail-meta-inside gridbit-clearfix">

    <?php if ( !(gridbit_get_option('hide_post_author_image_home')) ) { ?><?php echo wp_kses_post( gridbit_author_image() ); ?><?php } ?>

    <?php if ( !(gridbit_get_option('hide_post_author_home')) ) { ?><span class="gridbit-grid-post-author gridbit-grid-post-meta"><i class="far fa-user" aria-hidden="true"></i><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span><?php } ?>

    <?php if ( !(gridbit_get_option('hide_posted_date_home')) || (!(gridbit_get_option('hide_comments_link_home')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) { ?>
    <span class="gridbit-grid-post-meta">

    <?php if ( !(gridbit_get_option('hide_posted_date_home')) ) { ?><span class="gridbit-grid-post-date"><i class="far fa-clock" aria-hidden="true"></i><?php echo esc_html(get_the_date()); ?></span><?php } ?>

    <?php if ( gridbit_get_option('comments_count_home') ) { ?>
    <?php if ( !(gridbit_get_option('hide_comments_link_home')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbit-grid-post-comments gridbit-grid-post-meta-inline"><i class="far fa-comments" aria-hidden="true"></i><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0<span class="gridbit-sr-only"> Comment on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), sprintf( wp_kses( /* translators: %s: post title */ __( '1<span class="gridbit-sr-only"> Comment on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), sprintf( wp_kses( /* translators: %s: post title */ __( '%1$s<span class="gridbit-sr-only"> Comments on %2$s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), number_format_i18n( get_comments_number() ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php } else { ?>
    <?php if ( !(gridbit_get_option('hide_comments_link_home')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbit-grid-post-comments gridbit-grid-post-meta-inline"><i class="far fa-comments" aria-hidden="true"></i><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comment<span class="gridbit-sr-only"> on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php } ?>

    </span>
    <?php } ?>

    </div>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridbit_grid_footer_meta' ) ) :
 /**
  * Prints HTML with meta information for the categories, tags and comments.
  */
function gridbit_grid_footer_meta() {
    global $post; ?>
    <?php if ( (!(gridbit_get_option('hide_post_categories_home')) && has_category()) || (!(gridbit_get_option('hide_post_tags_home')) && has_tag()) ) { ?>
    <div class="gridbit-grid-post-details-meta gridbit-grid-post-block">
    <div class="gridbit-grid-post-details-meta-inside">
    <?php
    if ( !(gridbit_get_option('hide_post_categories_home')) && has_category() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list( esc_html__( ', ', 'gridbit' ) );
            if ( $categories_list ) { ?>
                <div class="gridbit-summary-post-cat-links gridbit-grid-post-details-meta-item"><i class="far fa-folder-open" aria-hidden="true"></i><?php echo wp_kses_post( $categories_list ); ?></div>
            <?php }
        }
    }

    if ( !(gridbit_get_option('hide_post_tags_home')) && has_tag() ) {
        if ( 'post' == get_post_type() ) {
            /* translators: used between list items, there is a space after the comma */
            $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridbit' ) );
            if ( $tags_list ) { ?>
                <div class="gridbit-summary-post-tags-links gridbit-grid-post-details-meta-item"><i class="fas fa-tags" aria-hidden="true"></i><?php echo wp_kses_post( $tags_list ); ?></div>
            <?php }
        }
    }
    ?>
    </div>
    </div>
    <?php } ?>
    <?php
}
endif;


if ( ! function_exists( 'gridbit_nongrid_postmeta' ) ) :
function gridbit_nongrid_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbit_get_option('hide_post_author_home')) || !(gridbit_get_option('hide_posted_date_home')) || (!(gridbit_get_option('hide_comments_link_home')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) || !(gridbit_get_option('hide_post_categories_home')) ) { ?>
    <div class="gridbit-entry-meta-single">
    <?php if ( !(gridbit_get_option('hide_post_author_home')) ) { ?><span class="gridbit-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_posted_date_home')) ) { ?><span class="gridbit-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_comments_link_home')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbit-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridbit-sr-only"> on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( !(gridbit_get_option('hide_post_categories_home')) ) { ?><?php gridbit_single_cats(); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridbit_single_cats' ) ) :
function gridbit_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridbit' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<span class="gridbit-entry-meta-single-cats"><i class="far fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="gridbit-sr-only">Posted in </span>%1$s', 'gridbit' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridbit_single_postmeta' ) ) :
function gridbit_single_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbit_get_option('hide_post_author')) || !(gridbit_get_option('hide_posted_date')) || (!(gridbit_get_option('hide_comments_link')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) || (!(gridbit_get_option('hide_post_categories')) && has_category()) || gridbit_get_option('show_post_edit') ) { ?>
    <div class="gridbit-entry-meta-single">
    <?php if ( !(gridbit_get_option('hide_post_author')) ) { ?><span class="gridbit-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_posted_date')) ) { ?><span class="gridbit-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_comments_link')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbit-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridbit-sr-only"> on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( (!(gridbit_get_option('hide_post_categories')) && has_category()) ) { ?><?php gridbit_single_cats(); ?><?php } ?>
    <?php if ( gridbit_get_option('show_post_edit') ) { ?><?php edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="gridbit-sr-only"> %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="edit-link">&nbsp;&nbsp;<i class="far fa-edit" aria-hidden="true"></i> ', '</span>' ); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridbit_page_postmeta' ) ) :
function gridbit_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridbit_get_option('hide_page_author')) || !(gridbit_get_option('hide_page_date')) || (!(gridbit_get_option('hide_page_comments')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) { ?>
    <div class="gridbit-entry-meta-single">
    <?php if ( !(gridbit_get_option('hide_page_author')) ) { ?><span class="gridbit-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_page_date')) ) { ?><span class="gridbit-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridbit_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridbit-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridbit-sr-only"> on %s</span>', 'gridbit' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;